@@ -1,17 +1,13 @@
 package Alien::mpg123;
-BEGIN {
-  $Alien::mpg123::AUTHORITY = 'cpan:GETTY';
-}
-{
-  $Alien::mpg123::VERSION = '0.002';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: mpg123 music player
-
+$Alien::mpg123::VERSION = '0.003';
 use parent 'Alien::Base';
 
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -20,7 +16,7 @@ Alien::mpg123 - mpg123 music player
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 AUTHOR
 
@@ -34,4 +30,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
